You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@sling.apache.org by fm...@apache.org on 2008/02/18 10:12:09 UTC

svn commit: r628656 - /incubator/sling/trunk/scripting/jsp-taglib/src/main/java/org/apache/sling/scripting/jsp/taglib/DefineObjectsTag.java

Author: fmeschbe
Date: Mon Feb 18 01:12:01 2008
New Revision: 628656

URL: http://svn.apache.org/viewvc?rev=628656&view=rev
Log:
SLING-252 use "currentNode" instead of "node" as the default name
for the variable holding the current Node (resource.adaptTo(Node.class))

Modified:
    incubator/sling/trunk/scripting/jsp-taglib/src/main/java/org/apache/sling/scripting/jsp/taglib/DefineObjectsTag.java

Modified: incubator/sling/trunk/scripting/jsp-taglib/src/main/java/org/apache/sling/scripting/jsp/taglib/DefineObjectsTag.java
URL: http://svn.apache.org/viewvc/incubator/sling/trunk/scripting/jsp-taglib/src/main/java/org/apache/sling/scripting/jsp/taglib/DefineObjectsTag.java?rev=628656&r1=628655&r2=628656&view=diff
==============================================================================
--- incubator/sling/trunk/scripting/jsp-taglib/src/main/java/org/apache/sling/scripting/jsp/taglib/DefineObjectsTag.java (original)
+++ incubator/sling/trunk/scripting/jsp-taglib/src/main/java/org/apache/sling/scripting/jsp/taglib/DefineObjectsTag.java Mon Feb 18 01:12:01 2008
@@ -53,9 +53,9 @@
     /**
      * Default name for the scripting variable referencing the JCR node
      * underlying the current <code>Resource</code> object if it is based on a
      * JCR node (value is "node").
      */
-    public static final String DEFAULT_NODE_NAME = "node";
+    public static final String DEFAULT_NODE_NAME = "currentNode";
 
     /**
      * Default name for the scripting variable referencing the mapped object
@@ -53,9 +53,9 @@
      * Default name for the scripting variable referencing the JCR node
      * underlying the current <code>Resource</code> object if it is based on a
-     * JCR node (value is "node").
+     * JCR node (value is "currentNode").
      */